searchData={"items":[{"type":"behaviour","title":"Vancouver.Tool","doc":"Tools enable LLMs to perform actions.\n\nYou can implement a tool as follows:\n\n    defmodule MyApp.Tools.CalculateSum do\n      use Vancouver.Tool\n\n      def name, do: \"calculate_sum\"\n      def description, do: \"Add two numbers together\"\n\n      def input_schema do\n        %{\n          \"type\" => \"object\",\n          \"properties\" => %{\n            \"a\" => %{\"type\" => \"number\"},\n            \"b\" => %{\"type\" => \"number\"}\n          },\n          \"required\" => [\"a\", \"b\"]\n        }\n      end\n\n      def run(conn, %{\"a\" => a, \"b\" => b}) do\n        send_text(conn, \"#{a + b}\")\n      end\n    end\n\nThe input schema must be a valid [JSON Schema](https://json-schema.org) object.","ref":"Vancouver.Tool.html"},{"type":"behaviour","title":"Sending responses - Vancouver.Tool","doc":"Tools provide helper functions to send valid MCP responses:\n\n- `send_json/2` - sends a JSON response\n- `send_text/2` - sends a text response\n- `send_error/2` - sends an error response","ref":"Vancouver.Tool.html#module-sending-responses"},{"type":"callback","title":"Vancouver.Tool.description/0","doc":"Human readable description of what the tool does.","ref":"Vancouver.Tool.html#c:description/0"},{"type":"callback","title":"Vancouver.Tool.input_schema/0","doc":"JSON Schema defining the tool's input parameters.","ref":"Vancouver.Tool.html#c:input_schema/0"},{"type":"callback","title":"Vancouver.Tool.name/0","doc":"Unique identifier for the tool.","ref":"Vancouver.Tool.html#c:name/0"},{"type":"callback","title":"Vancouver.Tool.run/2","doc":"Execute the tool with the given parameters.","ref":"Vancouver.Tool.html#c:run/2"},{"type":"function","title":"Vancouver.Tool.send_error/2","doc":"Sends an error response.","ref":"Vancouver.Tool.html#send_error/2"},{"type":"function","title":"Examples - Vancouver.Tool.send_error/2","doc":"iex> send_error(conn, \"an error occurred\")","ref":"Vancouver.Tool.html#send_error/2-examples"},{"type":"function","title":"Vancouver.Tool.send_json/2","doc":"Sends JSON response.","ref":"Vancouver.Tool.html#send_json/2"},{"type":"function","title":"Examples - Vancouver.Tool.send_json/2","doc":"iex> send_json(conn, %{id: 123})","ref":"Vancouver.Tool.html#send_json/2-examples"},{"type":"function","title":"Vancouver.Tool.send_text/2","doc":"Sends text response.","ref":"Vancouver.Tool.html#send_text/2"},{"type":"function","title":"Examples - Vancouver.Tool.send_text/2","doc":"iex> send_text(conn, \"hello\")","ref":"Vancouver.Tool.html#send_text/2-examples"},{"type":"extras","title":"Vancouver","doc":"# Vancouver\n\nVancouver makes it easy to add [Model Context Protocol (MCP)](https://modelcontextprotocol.io/introduction) functionality to your Phoenix/Bandit server. Vancouver handles initialization, request validation, and offers helper functions to simplify the creation of MCP tools.","ref":"readme.html"},{"type":"extras","title":"Getting started - Vancouver","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"1. Add dependency - Vancouver","doc":"In `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:vancouver, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#1-add-dependency"},{"type":"extras","title":"2. Create your tools - Vancouver","doc":"```elixir\ndefmodule MyApp.Tools.CalculateSum do\n  use Vancouver.Tool\n\n  def name, do: \"calculate_sum\"\n  def description, do: \"Add two numbers together\"\n\n  def input_schema do\n    %{\n      \"type\" => \"object\",\n      \"properties\" => %{\n        \"a\" => %{\"type\" => \"number\"},\n        \"b\" => %{\"type\" => \"number\"}\n      },\n      \"required\" => [\"a\", \"b\"]\n    }\n  end\n\n  def run(conn, %{\"a\" => a, \"b\" => b}) do\n    send_text(conn, \"#{a + b}\")\n  end\nend\n```","ref":"readme.html#2-create-your-tools"},{"type":"extras","title":"3. Add config - Vancouver","doc":"In `config.ex`:\n\n```elixir\nconfig :vancouver,\n  name: \"My MCP Server\",\n  version: \"1.0.0\",\n  tools: [\n    MyApp.Tools.CalculateSum\n  ]\n```","ref":"readme.html#3-add-config"},{"type":"extras","title":"4. Add your MCP route - Vancouver","doc":"In `router.ex`:\n\n```elixir\nforward \"/mcp\", Vancouver.Router\n```","ref":"readme.html#4-add-your-mcp-route"},{"type":"extras","title":"5. (Optional) Add to your MCP client - Vancouver","doc":"E.g. For Claude Desktop, you can modify your config `Settings -> Developer -> Edit config` as follows:\n\n    {\n        \"mcpServers\": {\n            \"MyApp\": {\n                \"command\": \"npx\",\n                \"args\": [\n                    \"mcp-remote\",\n                    \"http://localhost:4000/mcp\"\n                ]\n            }\n        }\n    }\n\nRun your server, and restart Claude to starting using your MCP tools. 🚀","ref":"readme.html#5-optional-add-to-your-mcp-client"},{"type":"extras","title":"FAQ - Vancouver","doc":"","ref":"readme.html#faq"},{"type":"extras","title":"Does Vancouver support all parts of the Model Context Protocol specification? - Vancouver","doc":"Not yet. Vancouver currently supports:\n\n- streamable HTTP transport\n- tools\n- sync responses (no streaming)\n- single messages (no batching)\n\nHowever, the library is simple enough that you should be able to modify it for your needs.\n\nFor more info on the protocol itself, see the [MCP User Guide](https://modelcontextprotocol.io/introduction).","ref":"readme.html#does-vancouver-support-all-parts-of-the-model-context-protocol-specification"},{"type":"extras","title":"Is Vancouver stable / ready for production? - Vancouver","doc":"No. This library is in early development. Expect breaking changes.","ref":"readme.html#is-vancouver-stable-ready-for-production"},{"type":"extras","title":"Why is this library called Vancouver? - Vancouver","doc":"Vancouver is the natural home of MCP (Mountain, Coffee, and Phoenix).","ref":"readme.html#why-is-this-library-called-vancouver"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}